@@ -11,7 +11,9 @@ class Global:
 
     def __init__(self, username: str, password: str) -> None:
         super(Global, self).__init__()
-        self.__occupation_insight = OccupationInsight(username=username,
+        url = "https://solutions-api.lightcast.io/smart-dataset/occupation-insight/v1/global",
+        self.__occupation_insight = OccupationInsight(url=url,
+                                                      username=username,
                                                       password=password,
                                                       insight_response=BasicOccupationInsightResponseParser(),
                                                       insight_request=OccupationInsightRequestClient())
